@@ -66,7 +66,13 @@ guint defaultkeys[K_NUM] = {
     GDK_Down,
     GDK_space,
     GDK_d,
-    GDK_t
+    GDK_t,
+    GDK_1,
+    GDK_2,
+    GDK_3,
+    GDK_4,
+    GDK_5,
+    GDK_6
 };
 
 guint keys[K_NUM];
@@ -187,7 +193,6 @@ void config_loadconfig (void)
     /* if there is no theme configured, then we fallback to DEFAULTTHEME */
     if (!p || !p[0])
     {
-      g_free (p);
       g_string_assign(currenttheme, DEFAULTTHEME);
       gconf_client_set_string (gconf_client, "/apps/gtetrinet/themes/theme_dir", currenttheme->str, NULL);
     }
@@ -231,6 +236,9 @@ void config_loadconfig (void)
         GTET_O_STRCPY(team, p);
         g_free(p);
     }
+	 
+    /* get the game mode */
+    gamemode = gconf_client_get_bool (gconf_client, "/apps/gtetrinet/player/gamemode", NULL);
 
     /* get the keys */
     p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/right", NULL);
@@ -305,6 +313,61 @@ void config_loadconfig (void)
     else
       keys[K_GAMEMSG] = defaultkeys[K_GAMEMSG];
 
+    p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/special1", NULL);
+    if (p)
+    {
+      keys[K_SPECIAL1] = gdk_keyval_to_lower (gdk_keyval_from_name (p));
+      g_free (p);
+    }
+    else
+      keys[K_SPECIAL1] = defaultkeys[K_SPECIAL1];
+
+    p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/special2", NULL);
+    if (p)
+    {
+      keys[K_SPECIAL2] = gdk_keyval_to_lower (gdk_keyval_from_name (p));
+      g_free (p);
+    }
+    else
+      keys[K_SPECIAL2] = defaultkeys[K_SPECIAL2];
+
+    p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/special3", NULL);
+    if (p)
+    {
+      keys[K_SPECIAL3] = gdk_keyval_to_lower (gdk_keyval_from_name (p));
+      g_free (p);
+    }
+    else
+      keys[K_SPECIAL3] = defaultkeys[K_SPECIAL3];
+
+    p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/special4", NULL);
+    if (p)
+    {
+      keys[K_SPECIAL4] = gdk_keyval_to_lower (gdk_keyval_from_name (p));
+      g_free (p);
+    }
+    else
+      keys[K_SPECIAL4] = defaultkeys[K_SPECIAL4];
+
+    p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/special5", NULL);
+    if (p)
+    {
+      keys[K_SPECIAL5] = gdk_keyval_to_lower (gdk_keyval_from_name (p));
+      g_free (p);
+    }
+    else
+      keys[K_SPECIAL5] = defaultkeys[K_SPECIAL5];
+
+    p = gconf_client_get_string (gconf_client, "/apps/gtetrinet/keys/special6", NULL);
+    if (p)
+    {
+      keys[K_SPECIAL6] = gdk_keyval_to_lower (gdk_keyval_from_name (p));
+      g_free (p);
+    }
+    else
+      keys[K_SPECIAL6] = defaultkeys[K_SPECIAL6];
+
+
     /* Get the timestamp option. */
     timestampsenable = gconf_client_get_bool (gconf_client, "/apps/gtetrinet/partyline/enable_timestamps", NULL);
 
@@ -489,6 +552,78 @@ keys_discard_changed (GConfClient *client,
   keys[K_DISCARD] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
 }
 
+void
+keys_special1_changed (GConfClient *client,
+                       guint cnxn_id,
+                       GConfEntry *entry)
+{
+
+  client = client;
+  cnxn_id = cnxn_id;
+
+  keys[K_SPECIAL1] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
+}
+
+void
+keys_special2_changed (GConfClient *client,
+                       guint cnxn_id,
+                       GConfEntry *entry)
+{
+
+  client = client;
+  cnxn_id = cnxn_id;
+
+  keys[K_SPECIAL2] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
+}
+
+void
+keys_special3_changed (GConfClient *client,
+                       guint cnxn_id,
+                       GConfEntry *entry)
+{
+
+  client = client;
+  cnxn_id = cnxn_id;
+
+  keys[K_SPECIAL3] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
+}
+
+void
+keys_special4_changed (GConfClient *client,
+                       guint cnxn_id,
+                       GConfEntry *entry)
+{
+
+  client = client;
+  cnxn_id = cnxn_id;
+
+  keys[K_SPECIAL4] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
+}
+
+void
+keys_special5_changed (GConfClient *client,
+                       guint cnxn_id,
+                       GConfEntry *entry)
+{
+
+  client = client;
+  cnxn_id = cnxn_id;
+
+  keys[K_SPECIAL5] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
+}
+
+void
+keys_special6_changed (GConfClient *client,
+                       guint cnxn_id,
+                       GConfEntry *entry)
+{
+
+  client = client;
+  cnxn_id = cnxn_id;
+
+  keys[K_SPECIAL6] = gdk_keyval_to_lower (gdk_keyval_from_name (gconf_value_get_string (gconf_entry_get_value (entry))));
+}
+
 void
 partyline_enable_timestamps_changed (GConfClient *client,
                                      guint cnxn_id,
