@@ -1,8 +1,12 @@
+#include <gnome.h>
+
 #define FIELDWIDTH 12
 #define FIELDHEIGHT 22
 
 typedef char FIELD[FIELDHEIGHT][FIELDWIDTH];
 
+extern char pnumrec;
+
 extern int playernum;
 extern char team[128], nick[128], specpassword[128];
 extern FIELD fields[7];
@@ -13,6 +17,7 @@ extern int gmsgstate;
 
 extern char specialblocks[256];
 extern int specialblocknum;
+extern gint list_issued;
 
 extern void tetrinet_inmessage (enum inmsg_type msgtype, char *data);
 extern void tetrinet_playerline (const char *text);
@@ -21,7 +26,7 @@ extern void tetrinet_updatefield (FIELD field);
 extern void tetrinet_sendfield (int reset);
 extern void tetrinet_resendfield (void);
 extern void tetrinet_redrawfields (void);
-extern int tetrinet_key (int keyval, char *str);
+extern int tetrinet_key (int keyval);
 extern void tetrinet_upkey (int keyval);
 
 extern void tetrinet_startgame (void);
